@@ -16,12 +16,13 @@
 #' @export
 setMethod("rowAnyMissings", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, force_block_processing = FALSE,
-                   ...) {
+                   ..., useNames = NA) {
             rowAnyNAs(x = x,
                     rows = rows,
                     cols = cols,
                     force_block_processing = force_block_processing,
-                    ...)
+                    ...,
+                    useNames = useNames)
           }
 )
 
